==> pegasus-merchandise-service-1.1.3-sources.jar: com/thebeastshop/pegasus/merchandise/domain/PcsSkuDomain.java <==
package com.thebeastshop.pegasus.merchandise.domain;

import java.util.List;
import java.util.Map;

import com.thebeastshop.pegasus.merchandise.cond.PcsSkuCond;
import com.thebeastshop.pegasus.merchandise.model.PcsSku;
import com.thebeastshop.pegasus.merchandise.model.PcsSkuBarcode;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuBarcodeVO;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuInfoVO;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuSalesPriceChangeVO;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuVO;

/**
 * @author gongjun
 * @since 2016-08-30
 */
public interface PcsSkuDomain extends BaseDomain<PcsSkuVO, PcsSku> {

    /**
     * 创建sku
     *
     * @param record
     * @return
     */
    Long create(PcsSku record);

    /**
     * 批量创建SKU
     * @param list
     * @return
     */
    List<Long> createSkus(List<PcsSku> list);

    List<Long> updateSkus(List<PcsSkuVO> list);

    /**
     * 更新sku
     *
     * @param record
     * @return
     */
    boolean update(PcsSku record);

    /**
     * 根据主键查找sku
     *
     * @param id
     * @return
     */
    PcsSku findById(long id);

    /**
     * 根据CODE查找sku
     *
     * @param code
     * @return
     */
    PcsSkuVO findByCode(String code);

    PcsSkuVO findByCode(String code, boolean widthFrontCategories, boolean withBackCategories);

    PcsSkuVO findByCode(String code, boolean widthFrontCategories, boolean withBackCategories, boolean withBuyerName);

    List<Map<String,Object>> findSkuCanSaleAndCanSeeByChannelCode(String channelCode);

    Map<String,Object> findSkuCanSaleAndCanSeeInfo(String channelCode,String skuCode);

    /**
     * 根据参数查找sku
     * @param arg0
     * @return
     */
    List<PcsSkuVO> findByNameOrCode(String arg0);

    /**
     * 根据条件查找sku
     *
     * @param cond
     * @return
     */
    List<PcsSkuVO> findByCond(PcsSkuCond cond);


    /**
     * 根据条件查找sku
     * 导出使用
     *
     * @param cond
     * @return
     */
    List<PcsSkuVO> findByCondForExport(PcsSkuCond cond);

    /**
     * 根据条件查找sku
     *
     * @param cond
     * @return
     */
    List<PcsSkuVO> findSkuTagByCond(PcsSkuCond cond);
    /**
     * 是否可以更新售价
     *
     * @param code
     * @return
     */
    Boolean canUpdateSalesPrice(String code);

    /**
     * 售价变更审批
     *
     * @param code
     * @param isPass
     * @return
     */
    Boolean auditSkuSalesPriceChange(String code, Boolean isPass, Integer type);

    /**
     * 根据skucode查找 审批中的售价变更记录
     *
     * @param code
     * @return
     */
    PcsSkuSalesPriceChangeVO findSkuSalesPriceChangeByCodeAndProcessing(String code);

    /**
     * 根据CODE集合查找sku
     *
     * @param codes
     * @return
     */
    List<PcsSku> findSkuByCodes(List<String> codes);

    /**
     * 转换sku
     *
     * @param sku
     * @param skuCustomMadeId
     * @return
     */
    Boolean convertSku(PcsSku sku, long skuCustomMadeId);


    List<PcsSkuVO> findByCodes(List<String> codes);

    List<PcsSkuVO> findByCodes(List<String> codes, boolean withCategories);

    /**
     * 所有SKU信息
     *
     * @return
     */
    List<PcsSkuInfoVO> allSkuInfo();

    /**
     * 所有SKU信息
     *
     * @return
     */
    PcsSkuInfoVO findStockByCode(String skuCode);

    List<PcsSkuVO> findChannelSkuForNoDistribute(PcsSkuCond cond);

    void setSkuChannel(List<String> skuCodeList, List<String> channelCodeList,Long operatorId);

    List<PcsSkuVO> findSkuByIds(List<Long> ids);

    Boolean canUpdateCostPrice(String code);

    Boolean canUpdateSupplier(String code);

    /**
     * sku总数计算
     * @param cond
     * @return
     */
    long countSkuByCond(PcsSkuCond cond);


    String getCrossBorderFlagByCodes(List<String> codes);

    Integer updateSkuCategoryNameByCode(String skuCategoryName, String skuCode);

    List<Integer> getSalesPriceByCodes(List<String> codes);

    List<Map> getSalesPriceByProdId(Long prodId);
    
    /**
     * 创建sku barcode
     * @param barcodeList
     */
    void createPcsSkuBarcode(List<PcsSkuBarcode> barcodeList);
    
    
    List<PcsSkuBarcodeVO> selectByBarCode(String barCode);

    List<PcsSkuVO> findSkuAuditByIds(List<Long> ids);

    /**
     * 查找指定skucode存在指定二级类目的个数
     * @param skuCodes
     * @param categoryIds
     * @return
     */
    Boolean isExistsSpecialCategory(List<String> skuCodes, List<Integer> categoryIds);

    /**
     * 查找指定二级类目下非指定skucode的个数
     * @param skuCodes
     * @param categoryIds
     * @return
     */
    Boolean isOnlyExistsSpecialCategory(List<String> skuCodes, List<Integer> categoryIds);

    
    public List<PcsSkuVO> findSkuBySupplierId(Long supplierId);
    
    public int updateSku(PcsSku record);
    
    /**
     * check成本价是否需要审批
     * @param record
     * @return
     */
    boolean costPriceNeedApproval(PcsSku record);
}

==> pegasus-merchandise-service-1.3.4-sources.jar: com/thebeastshop/pegasus/merchandise/domain/PcsSkuDomain.java <==
package com.thebeastshop.pegasus.merchandise.domain;

import java.util.List;
import java.util.Map;

import com.thebeastshop.pegasus.merchandise.cond.PcsSkuCond;
import com.thebeastshop.pegasus.merchandise.model.PcsSku;
import com.thebeastshop.pegasus.merchandise.model.PcsSkuBarcode;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuBarcodeVO;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuInfoVO;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuSalesPriceChangeVO;
import com.thebeastshop.pegasus.merchandise.vo.PcsSkuVO;

/**
 * @author gongjun
 * @since 2016-08-30
 */
public interface PcsSkuDomain extends BaseDomain<PcsSkuVO, PcsSku> {

    /**
     * 创建sku
     *
     * @param record
     * @return
     */
    Long create(PcsSku record);

    /**
     * 批量创建SKU
     * @param list
     * @return
     */
    List<Long> createSkus(List<PcsSku> list);

    List<Long> updateSkus(List<PcsSkuVO> list);

    /**
     * 更新sku
     *
     * @param record
     * @return
     */
    boolean update(PcsSku record);

    /**
     * 根据主键查找sku
     *
     * @param id
     * @return
     */
    PcsSku findById(long id);

    /**
     * 根据CODE查找sku
     *
     * @param code
     * @return
     */
    PcsSkuVO findByCode(String code);

    PcsSkuVO findByCode(String code, boolean widthFrontCategories, boolean withBackCategories);

    PcsSkuVO findByCode(String code, boolean widthFrontCategories, boolean withBackCategories, boolean withBuyerName);

    List<Map<String,Object>> findSkuCanSaleAndCanSeeByChannelCode(String channelCode);

    Map<String,Object> findSkuCanSaleAndCanSeeInfo(String channelCode,String skuCode);

    /**
     * 根据参数查找sku
     * @param arg0
     * @return
     */
    List<PcsSkuVO> findByNameOrCode(String arg0);

    /**
     * 根据条件查找sku
     *
     * @param cond
     * @return
     */
    List<PcsSkuVO> findByCond(PcsSkuCond cond);


    /**
     * 根据条件查找sku
     * 导出使用
     *
     * @param cond
     * @return
     */
    List<PcsSkuVO> findByCondForExport(PcsSkuCond cond);

    /**
     * 根据条件查找sku
     *
     * @param cond
     * @return
     */
    List<PcsSkuVO> findSkuTagByCond(PcsSkuCond cond);
    /**
     * 是否可以更新售价
     *
     * @param code
     * @return
     */
    Boolean canUpdateSalesPrice(String code);

    /**
     * 售价变更审批
     *
     * @param code
     * @param isPass
     * @return
     */
    Boolean auditSkuSalesPriceChange(String code, Boolean isPass, Integer type);

    /**
     * 根据skucode查找 审批中的售价变更记录
     *
     * @param code
     * @return
     */
    PcsSkuSalesPriceChangeVO findSkuSalesPriceChangeByCodeAndProcessing(String code);

    /**
     * 根据CODE集合查找sku
     *
     * @param codes
     * @return
     */
    List<PcsSku> findSkuByCodes(List<String> codes);

    /**
     * 转换sku
     *
     * @param sku
     * @param skuCustomMadeId
     * @return
     */
    Boolean convertSku(PcsSku sku, long skuCustomMadeId);

    /**
     * 转移sku
     * */
    boolean transferSku(List<String> skuCodes,Long buyerId);

    List<PcsSkuVO> findByCodes(List<String> codes);

    List<PcsSkuVO> findByCodes(List<String> codes, boolean withCategories);

    /**
     * 所有SKU信息
     *
     * @return
     */
    List<PcsSkuInfoVO> allSkuInfo();

    /**
     * 所有SKU信息
     *
     * @return
     */
    PcsSkuInfoVO findStockByCode(String skuCode);

    List<PcsSkuVO> findChannelSkuForNoDistribute(PcsSkuCond cond);

    void setSkuChannel(List<String> skuCodeList, List<String> channelCodeList,Long operatorId);

    List<PcsSkuVO> findSkuByIds(List<Long> ids);

    Boolean canUpdateCostPrice(String code);

    Boolean canUpdateSupplier(String code);

    /**
     * sku总数计算
     * @param cond
     * @return
     */
    long countSkuByCond(PcsSkuCond cond);


    String getCrossBorderFlagByCodes(List<String> codes);

    Integer updateSkuCategoryNameByCode(String skuCategoryName, String skuCode);

    List<Integer> getSalesPriceByCodes(List<String> codes);

    List<Map> getSalesPriceByProdId(Long prodId);
    
    /**
     * 创建sku barcode
     * @param barcodeList
     */
    void createPcsSkuBarcode(List<PcsSkuBarcode> barcodeList);
    
    
    List<PcsSkuBarcodeVO> selectByBarCode(String barCode);

    List<PcsSkuVO> findSkuAuditByIds(List<Long> ids);

    /**
     * 查找指定skucode存在指定二级类目的个数
     * @param skuCodes
     * @param categoryIds
     * @return
     */
    Boolean isExistsSpecialCategory(List<String> skuCodes, List<Integer> categoryIds);

	List<PcsSkuVO> findSkuQualifyByCond(PcsSkuCond cond);

	List<PcsSkuVO> findSkuQualifyByInCond(PcsSkuCond cond);

    List<PcsSkuVO> findSharedAptitude();

    List<PcsSkuVO> findSharedImportDoc();
    /**
     * 查找指定二级类目下非指定skucode的个数
     * @param skuCodes
     * @param categoryIds
     * @return
     */
    Boolean isOnlyExistsSpecialCategory(List<String> skuCodes, List<Integer> categoryIds);


    public List<PcsSkuVO> findSkuBySupplierId(Long supplierId);

    public int updateSku(PcsSku record);

    /**
     * check成本价是否需要审批
     * @param record
     * @return
     */
    boolean costPriceNeedApproval(PcsSku record);


    Integer getMonthlyByCodes(List<String> skuCodes);
}
